/*------------------------------------------------------------------------
    File        : EirDamageValidator.cls
    Author(s)   : marc
    Created     : 31-08-2018 16:57:10
    Notes       : Customized UI Controller Class for EirDamage.cls
  ----------------------------------------------------------------------*/

USING Progress.Lang.*.
USING Progress.Json.ObjectModel.*.
USING WebApp.System.Session.*.
USING WebApp.System.Manager.*.
USING WebApp.System.Util.*.
USING WebApp.EC.Util.*.


BLOCK-LEVEL ON ERROR UNDO, THROW.

CLASS WebApp.EC.BL.EirDamageUIController
      INHERITS WebApp.System.BusinessLogic.UIController:

  {"WebApp/EC/BL/EirDamage.i"}

  DEFINE PUBLIC PROPERTY EirDamageBE AS WebApp.EC.BL.EirDamageBE NO-UNDO
  GET.
  PRIVATE SET.

  CONSTRUCTOR PUBLIC EirDamageUIController (  ):

    SUPER ().
    /* REMOVE THIS COMMENT WHEN USING METHODS FROM BE 'EirDamageBE'
    EirDamageBE = CAST(THIS-OBJECT:ParentBE, WebApp.EC.BL.EirDamageBE).
    */

  END CONSTRUCTOR.


  /*------------------------------------------------------------------------------
   Purpose: Manipulate then Senstivity and Field values of fields in the UI
   Notes: @param pcInvokeField Invoked field
          @param plNewRow Row is new record
          @param phRowBuffer buffer to row data
          @param dsFieldEnabledValue proDataset with field values and senstitivity information

   Syntax:
            SetSens(fieldname , logical).

              fieldname
                character value corresponds the literal name of field in
                the view model/dataset.

              logical
                logical expression indicaties fields sensitive or incensitive

            Example:

                SetSens("date"         , TRUE).
                SetSens("des"          , TRUE).
                SetSens("code"         , lNewRow).

  ------------------------------------------------------------------------------*/
  METHOD PUBLIC OVERRIDE VOID UIFieldControl( INPUT pcInvokeField AS CHARACTER,
                                              INPUT plNewRow      AS LOGICAL,
                                              INPUT phRowBuffer   AS HANDLE,
                                              OUTPUT DATASET dsFieldEnabledValue):


  END METHOD.

/*------------------------------------------------------------------------------
   Purpose: Set Row Meta Data for Color and Symolic Fields to apply to Grid in the fontend
   Notes:    @param phBuffer buffer to current record

   Syntax:
              Set Forground or background color of entire row:

              oRMDHelper:setRowFgColor(rgb_value).
              oRMDHelper:setRowBgColor(rgb_value).

              reg_value:
                RGB Value in HEX notation #xxxxx,
                             seperate red, geen, blue values or
                             RGB-VALUE

              example:
                oRMDHelper:setRowFgColor(0,0,0).
                oRMDHelper:setRowBgColor(160,160,160).

                  -- or --

                oRMDHelper:setRowFgColor(RGB-VALUE(0,0,0)).
                oRMDHelper:setRowBgColor(RGB-VALUE(160,160,160)).

                  -- or ---

                oRMDHelper:setRowFgColor("#000000").
                oRMDHelper:setRowBgColor("#A0A0A0").


              Set Forground or background color of one field:

              oRMDHelper:setFieldFgColor(fieldname , rgb_value).
              oRMDHelper:setFieldBgColor(fieldname , rgb_value).

               rgb_value:
                RGB Value in HEX notation #xxxxx,
                             seperate red, geen, blue values or
                             RGB-VALUE

              fieldname
                character value corresponds the literal name of field in
                the view model/dataset.

              reg_value:
                RGB Value in HEX notation #xxxxx,
                             seperate red, geen, blue values or
                             RGB-VALUE

            Example:

                oRMDHelper:setFieldFgColor("date", 0,0,0).
                oRMDHelper:setFieldBgColor("date",160,160,160).

                  -- or --

                oRMDHelper:setFieldFgColor("date",RGB-VALUE(0,0,0)).
                oRMDHelper:setFieldBgColor("date",RGB-VALUE(160,160,160)).

                  -- or ---

                oRMDHelper:setFieldFgColor("date","#000000").
                oRMDHelper:setFieldBgColor("date","#A0A0A0").

              Set Symbolic field:

                oRMDHelper:setFieldSymbol(fieldname , symbol-name).

                fieldname
                  character value corresponds the literal name of field in
                  the view model/dataset.

                symbol-name:
                  name of the symbolic icon e.g. font awesome classname

              Example:

                 oRMDHelper:setFieldSymbol("dsp_priority" , "fa-long-arrow-up").
  ------------------------------------------------------------------------------*/
  METHOD PUBLIC OVERRIDE VOID UIGridControl (INPUT phBuffer AS HANDLE):


  END METHOD.

  /*------------------------------------------------------------------------------
   Purpose: Fill values of combox/listbox for EirDamage. 
   Notes:   @param pcListName combo/listbox name

   Syntax:  
            
  ------------------------------------------------------------------------------*/
  METHOD PUBLIC OVERRIDE VOID UIGetList( INPUT pcListName AS CHARACTER ):
  
    DEFINE VARIABLE oItem        AS JsonObject NO-UNDO.

    CASE pcListName:
    WHEN  "[type here list-name]"
    THEN DO:
    /* Sample code: add item to list
      oItem = NEW JsonObject().
      oItem:Add("value", "[type here value]"
      oItem:Add("text" , "[type here text]"

      /* Add item to array */
      ListItems:Add(oItem).
    */
    END.
    END CASE.

  END METHOD.


END CLASS.
